ecmm428 - The `pycart` package
==============================

![GitHub](https://img.shields.io/github/license/ARundle01/ecmm428-pycart)
![GitHub code size in bytes](https://img.shields.io/github/repo-size/ARundle01/ecmm428-pycart)
![GitHub last commit](https://img.shields.io/github/last-commit/ARundle01/ecmm428-pycart)
![GitHub top language](https://img.shields.io/github/languages/top/ARundle01/ecmm428-pycart)
[![Documentation Status](https://readthedocs.org/projects/ecmm428-pycart/badge/?version=latest)](https://ecmm428-pycart.readthedocs.io/en/latest/?badge=latest)

## Contributors
Contributors to this project are
- Alex Rundle (ARundle01)

## License
This project is licensed under the BSD 3-Clause License

SPDX-License-Identifier: BSD-3-Clause

## Installation
### Using Pip
Make sure you have the latest version of PIP installed:
```pycon
py -m pip install --upgrade pip
```

This package is currently hosted on PyPi and TestPyPi, as it is currently in unstable development. To install 
and use this package from PyPi:
```pycon
py -m pip install pycart
```

To install
and use this package from TestPyPi:
```pycon
py -m pip install -i https://test.pypi.org/simple/ pycart
```

## Pre-requisites
All code in this Repository and Package was developed and tested on Windows 10.

This Repository requires:
- **Python >=3.9**

## Read the Docs!
Further information about `pycart` can be found [here](https://ecmm428-pycart.readthedocs.io/en/latest/), 
including further installation and dependency details, a quickstart guide and API reference.